// $Id: FirmwareSwitch.cc,v 1.5 2005/11/12 21:53:20 m9710797 Exp $

#include "FirmwareSwitch.hh"
#include "BooleanSetting.hh"

namespace openmsx {

FirmwareSwitch::FirmwareSwitch(CommandController& commandController)
	: setting(new BooleanSetting(commandController, "firmwareswitch",
	          "This setting controls the firmware switch",
	          false))
{
}

FirmwareSwitch::~FirmwareSwitch()
{
}

bool FirmwareSwitch::getStatus() const
{
	return setting->getValue();
}

} // namespace openmsx
